pub struct MissingTable { /* private fields */ }Expand description
A struct for missing information in a tabular dataset.
Implementations
Sourceimpl MissingTable
impl MissingTable
Sourcepub const fn fully_observed(&self) -> &Set<usize>
pub const fn fully_observed(&self) -> &Set<usize>
Get the set of fully observed variables.
Returns
A reference to the set of fully observed variables.
Sourcepub const fn partially_observed(&self) -> &Set<usize>
pub const fn partially_observed(&self) -> &Set<usize>
Get the set of partially observed variables.
Returns
A reference to the set of partially observed variables.
Sourcepub const fn missing_mask(&self) -> &Array2<bool>
pub const fn missing_mask(&self) -> &Array2<bool>
Get the missing mask indicating the presence of missing values in the table.
Returns
A reference to the missing mask.
Sourcepub const fn missing_mask_by_cols(&self) -> &Array1<bool>
pub const fn missing_mask_by_cols(&self) -> &Array1<bool>
Get the missing mask indicating the presence of missing values in each column.
Returns
A reference to the missing mask by columns.
Sourcepub const fn missing_mask_by_rows(&self) -> &Array1<bool>
pub const fn missing_mask_by_rows(&self) -> &Array1<bool>
Get the missing mask indicating the presence of missing values in each row.
Returns
A reference to the missing mask by rows.
Sourcepub const fn missing_count(&self) -> usize
pub const fn missing_count(&self) -> usize
Sourcepub const fn missing_count_by_cols(&self) -> &Array1<usize>
pub const fn missing_count_by_cols(&self) -> &Array1<usize>
Get the count of missing values in each column.
Returns
A reference to the missing count by columns.
Sourcepub const fn missing_count_by_rows(&self) -> &Array1<usize>
pub const fn missing_count_by_rows(&self) -> &Array1<usize>
Sourcepub const fn missing_rate(&self) -> f64
pub const fn missing_rate(&self) -> f64
Sourcepub const fn missing_rate_by_cols(&self) -> &Array1<f64>
pub const fn missing_rate_by_cols(&self) -> &Array1<f64>
Sourcepub const fn missing_rate_by_rows(&self) -> &Array1<f64>
pub const fn missing_rate_by_rows(&self) -> &Array1<f64>
Sourcepub const fn missing_correlation(&self) -> &Array2<f64>
pub const fn missing_correlation(&self) -> &Array2<f64>
Get the missing (Pearson) correlation matrix.
Returns
A reference to the missing correlation matrix.
Sourcepub const fn missing_covariance(&self) -> &Array2<f64>
pub const fn missing_covariance(&self) -> &Array2<f64>
Get the missing (unbiased) covariance matrix.
Returns
A reference to the missing covariance matrix.
Sourcepub const fn complete_cols_count(&self) -> usize
pub const fn complete_cols_count(&self) -> usize
Get the count of complete columns (without any missing values) in the table.
Returns
The count of complete columns.
Sourcepub const fn complete_rows_count(&self) -> usize
pub const fn complete_rows_count(&self) -> usize
Get the count of complete rows (without any missing values) in the table.
Returns
The count of complete rows.