DiGraph

Struct DiGraph 

pub struct DiGraph { /* private fields */ }
A struct representing a directed graph using an adjacency matrix.

Implementations

Source

impl DiGraph

pub fn parents(&self, x: &Set<usize>) -> Result<Set<usize>>

Returns the parents of a set of vertices.

Arguments
  • x - The set of vertices for which to find the parents.
Errors
  • If any vertex is out of bounds.
Returns

The parents of the vertices.

pub fn ancestors(&self, x: &Set<usize>) -> Result<Set<usize>>

Returns the ancestors of a set of vertices.

Arguments
  • x - The set of vertices for which to find the ancestors.
Errors
  • If any vertex is out of bounds.
Returns

The ancestors of the vertices.

pub fn children(&self, x: &Set<usize>) -> Result<Set<usize>>

Returns the children of a set of vertices.

Arguments
  • x - The set of vertices for which to find the children.
Errors
  • If any vertex is out of bounds.
Returns

The children of the vertices.

pub fn descendants(&self, x: &Set<usize>) -> Result<Set<usize>>

Returns the descendants of a set of vertices.

Arguments
  • x - The set of vertices for which to find the descendants.
Errors
  • If any vertex is out of bounds.
Returns

The descendants of the vertices.