CatSupport

Type Alias CatSupport 

pub type CatSupport = Map<String, Set<String>>;
A type alias for the support of categorical distributions. Represented as a map from variable names to their possible discrete states.

Aliased Type

pub struct CatSupport { /* private fields */ }