pub struct Error {
pub kind: ErrorKind,
pub location: &'static Location<'static>,
}Expand description
The error type for this crate.
Fields
kind: ErrorKindThe error kind.
location: &'static Location<'static>The location of the error.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn Probability(stats: &str) -> Self
pub fn Probability(stats: &str) -> Self
An error related to probability calculations.
Sourcepub fn MissingData(stats: &str) -> Self
pub fn MissingData(stats: &str) -> Self
An error related to missing data.
Sourcepub fn Unreachable(stats: &str) -> Self
pub fn Unreachable(stats: &str) -> Self
An error related to unreachable code.
Sourcepub fn IndexOutOfBounds(u: usize) -> Self
pub fn IndexOutOfBounds(u: usize) -> Self
Index is out of bounds.
Sourcepub fn NonUniqueLabels() -> Self
pub fn NonUniqueLabels() -> Self
Labels must be unique.
Sourcepub fn SetsNotDisjoint(s1: &str, s2: &str) -> Self
pub fn SetsNotDisjoint(s1: &str, s2: &str) -> Self
An error indicating that two sets must be disjoint.
Sourcepub fn SubsetMismatch(s1: &str, s2: &str) -> Self
pub fn SubsetMismatch(s1: &str, s2: &str) -> Self
An error indicating that one set must be a subset of another.
Sourcepub fn InvalidParameter(s1: &str, s2: &str) -> Self
pub fn InvalidParameter(s1: &str, s2: &str) -> Self
An error indicating that a parameter is invalid.
Sourcepub fn PriorKnowledgeConflict(stats: &str) -> Self
pub fn PriorKnowledgeConflict(stats: &str) -> Self
An error indicating a conflict in prior knowledge.
Sourcepub fn LabelMismatch(s1: &str, s2: &str) -> Self
pub fn LabelMismatch(s1: &str, s2: &str) -> Self
An error indicating that the labels of the graphs are incompatible.
Sourcepub fn MissingSufficientStatistics() -> Self
pub fn MissingSufficientStatistics() -> Self
An error indicating that sufficient statistics are missing.
Sourcepub fn MissingLogLikelihood() -> Self
pub fn MissingLogLikelihood() -> Self
An error indicating that the log-likelihood is missing.
Sourcepub fn MissingHeader() -> Self
pub fn MissingHeader() -> Self
An error indicating that a CSV file is missing headers.
Sourcepub fn IncompatibleShape(s1: &str, s2: &str) -> Self
pub fn IncompatibleShape(s1: &str, s2: &str) -> Self
An error indicating that the shape of the data is incompatible.
Sourcepub fn MissingState(stats: &str) -> Self
pub fn MissingState(stats: &str) -> Self
An error indicating that a state is missing.
Sourcepub fn MissingLabel(stats: &str) -> Self
pub fn MissingLabel(stats: &str) -> Self
An error indicating that a label is missing.
Sourcepub fn MissingValue(u1: usize, u2: usize) -> Self
pub fn MissingValue(u1: usize, u2: usize) -> Self
An error indicating that a value is missing.
Sourcepub fn ConstructionError(stats: &str) -> Self
pub fn ConstructionError(stats: &str) -> Self
An error indicating that an object construction failed.
Sourceimpl Error
impl Error
Sourcepub fn Utf8(err: FromUtf8Error) -> Self
pub fn Utf8(err: FromUtf8Error) -> Self
An error related to UTF-8 conversion.
Sourcepub fn ParseFloat(err: ParseFloatError) -> Self
pub fn ParseFloat(err: ParseFloatError) -> Self
An error related to float parsing.
Sourcepub fn NdarrayShape(err: ShapeError) -> Self
pub fn NdarrayShape(err: ShapeError) -> Self
An error related to ndarray shape operations.
Sourcepub fn NdarrayMinMax(err: MinMaxError) -> Self
pub fn NdarrayMinMax(err: MinMaxError) -> Self
An error related to ndarray statistics.
Sourcepub fn RandDistrUniform(err: Error) -> Self
pub fn RandDistrUniform(err: Error) -> Self
An error related to random distribution uniform sampling.