pub enum ErrorKind {
Show 36 variants
Io(Arc<Error>),
Csv(Arc<Error>),
Json(Arc<Error>),
Utf8(FromUtf8Error),
ParseFloat(ParseFloatError),
NdarrayShape(ShapeError),
NdarrayMinMax(MinMaxError),
RandDistrUniform(Error),
Linalg(String),
Probability(String),
Parsing(String),
MissingData(String),
Stats(String),
RandDistr(String),
Shape(String),
Unreachable(String),
Poison(String),
IndexOutOfBounds(usize),
NonUniqueLabels,
EmptySet(String),
SetsNotDisjoint(String, String),
SubsetMismatch(String, String),
NotADag,
InvalidParameter(String, String),
PriorKnowledgeConflict(String),
LabelMismatch(String, String),
MissingSufficientStatistics,
MissingLogLikelihood,
MissingHeader,
IncompatibleShape(String, String),
MissingState(String),
MissingLabel(String),
NanValue,
MissingValue(usize, usize),
ConstructionError(String),
Other(Arc<Box<dyn Error + Send + Sync>>),
}Expand description
The error kind type for this crate.
Variants
Io(Arc<Error>)
An error related to I/O operations.
Csv(Arc<Error>)
An error related to CSV parsing.
Json(Arc<Error>)
An error related to JSON parsing.
Utf8(FromUtf8Error)
An error related to UTF-8 conversion.
ParseFloat(ParseFloatError)
An error related to float parsing.
NdarrayShape(ShapeError)
An error related to ndarray shape operations.
NdarrayMinMax(MinMaxError)
An error related to ndarray statistics.
RandDistrUniform(Error)
An error related to random distribution uniform sampling.
Linalg(String)
An error related to linear algebra operations.
Probability(String)
An error related to probability calculations.
Parsing(String)
An error related to parsing.
MissingData(String)
An error related to missing data.
Stats(String)
An error related to statistics.
RandDistr(String)
An error related to random distributions.
Shape(String)
An error related to shape.
Unreachable(String)
An error related to unreachable code.
Poison(String)
An error related to lock poisoning.
IndexOutOfBounds(usize)
Index is out of bounds.
NonUniqueLabels
Labels must be unique.
EmptySet(String)
An error indicating that a set cannot be empty.
SetsNotDisjoint(String, String)
An error indicating that two sets must be disjoint.
SubsetMismatch(String, String)
An error indicating that one set must be a subset of another.
NotADag
An error indicating that the graph must be a DAG.
InvalidParameter(String, String)
An error indicating that a parameter is invalid.
PriorKnowledgeConflict(String)
An error indicating a conflict in prior knowledge.
LabelMismatch(String, String)
An error indicating that the labels of the graphs are incompatible.
MissingSufficientStatistics
An error indicating that sufficient statistics are missing.
MissingLogLikelihood
An error indicating that the log-likelihood is missing.
MissingHeader
An error indicating that a CSV file is missing headers.
IncompatibleShape(String, String)
An error indicating that the shape of the data is incompatible.
MissingState(String)
An error indicating that a state is missing.
MissingLabel(String)
An error indicating that a label is missing.
NanValue
An error indicating that a value is NaN.
MissingValue(usize, usize)
An error indicating that a value is missing.
ConstructionError(String)
An error indicating that an object construction failed.
Other(Arc<Box<dyn Error + Send + Sync>>)
Other errors.